@@ -183,6 +183,10 @@ FKM.noise <-
         startU=startU/apply(startU,1,sum)
         cat("The sums of the rows of startU must be equal to 1: the rows of startU will be normalized to unit row-wise sum ",fill=TRUE)
       }
+	  if (check==0)
+	  {
+		RS=1
+	  }
       if (missing(index))
       {
         index = "SIL.F"
