@@ -1,5 +1,4 @@
-Hraw <-
-function (X, H)
+Hraw <- function (X, H)
 {
 if (missing(X))
 stop("The data set must be given")
@@ -8,7 +7,7 @@ stop("The data set X is empty")
 X=as.matrix(X)
 if (any(is.na(X)))
 stop("The data set X must not contain NA values")
-if (!is.numeric(X)) 
+if (!is.numeric(X))
 stop("The data set X is not a numeric data.frame or matrix")
 if (missing(H))
 stop("The prototype matrix H must be given")
@@ -17,9 +16,9 @@ stop("The prototype matrix H is empty")
 H=as.matrix(H)
 if (any(is.na(H)))
 stop("The prototype matrix H must not contain NA values")
-if (!is.numeric(H)) 
+if (!is.numeric(H))
 stop("The prototype matrix H is not numeric")
-if (ncol(H)!=ncol(X)) 
+if (ncol(H)!=ncol(X))
 stop("The numbers of columns of H and X must be the same")
 k=nrow(H)
 p=ncol(H)
@@ -33,4 +32,4 @@ colnames(H.raw)=paste("Var",1:p,sep=" ")
 else
 colnames(H.raw)=colnames(H)
 return(H.raw)
-}
\ No newline at end of file
+}
