@@ -1,5 +1,4 @@
-VAT <-
-function (Xca)
+VAT <- function (Xca)
 {
 if (missing(Xca))
 stop("The data set must be given")
@@ -34,4 +33,4 @@ Rstar=R[P,rev(P)]
 #x=seq(0,length=nrow(Rstar)+1)
 #image(x,x,Rstar,col = grey(seq(0, 1, length = 256)),xaxp=c(1,nrow(Rstar),1),yaxp=c(1,nrow(Rstar),1))
 image(Rstar,col=grey(seq(0, 1, length = 256)),xlab="",ylab="",xaxt="n",yaxt="n",main="VAT")
-}
\ No newline at end of file
+}
